@@ -11,12 +11,10 @@
 
 void help(void);
 
-char *source_csname=SOURCE_CHARSET, *dest_csname=TARGET_CHARSET;
-char *format_name="ascii";
 
 int signature_check = 1;
 int wrap_margin = WRAP_MARGIN;
-int (*get_unicode_char)(FILE *f) =get_8bit_char;
+int (*get_unicode_char)(FILE *f,long *offset) =NULL;
 
 char *input_buffer, *output_buffer;
 #ifdef __WATCOMC__
@@ -48,7 +46,7 @@ if (tempname) {
   free(tempname);
 }
 #endif
-while ((c=getopt(argc,argv,"s:d:f:taubxwm:"))!=-1) {
+while ((c=getopt(argc,argv,"ls:d:f:taubxv8wm:"))!=-1) {
    switch (c) {
    case 's':
 	check_charset(&source_csname,optarg);
@@ -66,7 +64,13 @@ while ((c=getopt(argc,argv,"s:d:f:taubxwm:"))!=-1) {
         format_name=strdup("ascii");
         break;
    case 'u':
-         get_unicode_char = get_utf16lsb;
+         get_unicode_char = get_word8_char;
+         break;
+   case '8':
+         get_unicode_char = get_8bit_char;
+         break;
+   case 'v':
+         verbose=1;
          break;
    case 'w':
          wrap_margin=0; /* No wrap */
@@ -80,6 +84,7 @@ while ((c=getopt(argc,argv,"s:d:f:taubxwm:"))!=-1) {
          }
          break;
       }
+   case 'l': list_charsets(); exit(0);	     
    case 'b': signature_check =0; break;
    case 'x': unknown_as_hex = 1; break;
    default:
@@ -131,7 +136,7 @@ if (optind == argc) {
      exit(0);
   }
   if (input_buffer) setvbuf(stdin,input_buffer,_IOFBF,FILE_BUFFER);
-  process_file(stdin);
+  analyze_format(stdin);
   return 0;
 }
 c=0;
@@ -142,7 +147,7 @@ for (i=optind;i<argc;i++) {
        exit(1);
      }
      if (input_buffer) setvbuf(stdin,input_buffer,_IOFBF,FILE_BUFFER);
-     process_file(stdin);
+     analyze_format(stdin);
      stdin_processed=1;
   } else {
     f=fopen(argv[i],"rb");
@@ -155,68 +160,16 @@ for (i=optind;i<argc;i++) {
     if (setvbuf(f,input_buffer,_IOFBF,FILE_BUFFER)) {
        perror(argv[i]);
     }
-    process_file(f);
+    analyze_format(f);
     fclose(f);
   }
 }
 
   return c;
 }
-/********************************************************************/
-/*  Reads configuration file                                        */
-/*                                                                  */
-/********************************************************************/
-void read_config_file(const char* filename)
-{ 
-  FILE *f=fopen(add_exe_path(filename),"rb");
-  char *name,*value,line[1024],*c;
-  int lineno=0;
-  if (!f) return;
-  while (!feof(f)) {
-    fgets(line,1024,f);
-    if (feof(f)) break;
-    lineno++;
-    name=line;
-    while (*name&&isspace(*name)) name++;
-    if (!*name||*name == '#') continue;
-    for (value=name;*value&&(isalnum(*value)||*value=='_'); value++);  
-    if (*value=='=') {
-       *value=0;value++;
-    } else {
-      *value=0;value++;
-      while(*value&&isspace(*value)) value++;
-      if (*value != '=' ) {
-        fprintf(stderr,"Error %s(%d): name = value syntax expected\n",
-              filename,lineno);
-        continue;
-      }
-      while(*value&&isspace(*value)) value++;
-    }
-    for (c=value;*c&&!isspace(*c);c++);
-    if (value==c) {
-        fprintf(stderr,"Error %s(%d): name = value syntax expected\n",
-              filename,lineno);
-        continue;
-    }
-    *c=0;
-    if (!strcmp(name,"source_charset")) {
-       source_csname=strdup(value);
-    } else if (!strcmp(name,"target_charset")) {
-       dest_csname=strdup(value);
-    } else if (!strcmp(name,"format")) {
-       format_name=strdup(value);
-    } else if (!strcmp(name,"charset_path")) {
-       charset_path = strdup(value);
-    } else if (!strcmp(name,"map_path")) {
-       map_path = strdup(value);
-    }
- }
- fclose(f);
-}
 /************************************************************************/
 /* Displays  help message                                               */
 /************************************************************************/
 void help (void) {
-
-  printf("Usage: catdoc [-ubtawx] [-m number] [-s charset] [-t charset] files\n");
+  printf("Usage:\n catdoc [-vu8btawxl] [-m number] [-s charset] [-d charset] [ -f format] files\n");
 }
