@@ -1,6 +1,9 @@
 #ifndef CATDOC_H
 #define CATDOC_H
-
+/* There is some strange thing on aix */
+#if (defined(_AIX)||defined(___AIX)) && !defined(__unix)
+# define __unix 1
+#endif
 #include <stdio.h>
 #include <ctype.h>
 /*
@@ -8,8 +11,8 @@
  *
  */
 
-#ifdef __unix
-#ifndef USERC
+#if defined(__unix) || defined(__unix__)
+#ifndef USERRC
 #define USERRC ".catdocrc"
 #endif
 #ifndef SYSTEMRC
@@ -20,8 +23,7 @@
 #endif
 /* Macro to add executable directory in place of %s in path.
    Not usable in Unix, where executable can have more then one
-   link and configuration files are usially kept separately
-   from executables
+   link and configuration files are usially kept separately   from executables
  */
 #define add_exe_path(name) name
 #define LIST_SEP ':'
@@ -39,7 +41,7 @@ char *add_exe_path(const char* name);
 #endif
 
 #define CHARSET_EXT ".txt"
-#ifdef __unix
+#if defined(__unix) || defined(__unix__)
 #ifndef TARGET_CHARSET
 #define TARGET_CHARSET "koi8-r"
 #endif
@@ -98,6 +100,10 @@ typedef short int  ** CHARSET;
 typedef char *** SUBSTMAP;
 
 extern short int *source_charset;
+extern char bad_char[]; /* defines one-symbol string to replace unknown unicode chars */
+extern char *source_csname;
+extern char *dest_csname;
+extern char *format_name;
 extern CHARSET target_charset;
 extern SUBSTMAP spec_chars;
                 /* Defines unicode chars which should be
@@ -109,11 +115,18 @@ extern SUBSTMAP replacements;
                     mapped to some character sequence if no
                     corresponding character exists in the target charset
                     i.e copyright sign */
-extern int (*get_unicode_char)(FILE *f); /* pointer to function which gets
+extern int verbose; /* if true, some additional information would be
+		       printed. defined in analyze.c */
+extern int (*get_unicode_char)(FILE *f,long *offset); 
+/* pointer to function which gets
                                      a char from stream */
 
-extern int get_utf16lsb (FILE *f);
-extern int get_8bit_char (FILE *f);
+extern int get_utf16lsb (FILE *f,long *offset);
+extern int get_utf16msb (FILE *f,long *offset);
+extern int get_utf8 (FILE *f,long *offset);
+extern int get_8bit_char (FILE *f,long *offset);
+
+extern int get_word8_char (FILE *f,long *offset);
 extern  short int *read_charset(char *filename);
 extern CHARSET make_reverse_map (short int *charset);
 
@@ -121,7 +134,7 @@ extern int to_unicode (short int *charset, int c) ;
 
 extern int from_unicode (CHARSET charset, int u) ;
 
-extern char* map_char(int unicode_char);
+extern char* convert_char(int unicode_char);
 
 extern char* map_path, *charset_path;
 extern int signature_check;
@@ -135,8 +148,14 @@ extern int longest_sequence;/* for checking which value of wrap_margin
 char *map_subst(SUBSTMAP map,int uc);
 
 void check_charset(char **filename,const char *charset);
-void process_file(FILE *f);
+void process_file(FILE *f,long stop);
+void copy_out(FILE *f, char *header);
 void output_paragraph(unsigned short int *buffer) ;
+void parse_rtf(FILE *f);
+/* format recognition*/
+void analyze_format(FILE *f);
+void list_charsets(void);
+void parse_word_header(unsigned char *buffer,FILE *f,int offset,long curpos);
 /* large buffers for file IO*/
 extern char *input_buffer,*output_buffer;
 #endif
